# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ServiceMeshArgs', 'ServiceMesh']

@pulumi.input_type
class ServiceMeshArgs:
    def __init__(__self__, *,
                 network: pulumi.Input['ServiceMeshNetworkArgs'],
                 cluster_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 cluster_spec: Optional[pulumi.Input[builtins.str]] = None,
                 customized_prometheus: Optional[pulumi.Input[builtins.bool]] = None,
                 edition: Optional[pulumi.Input[builtins.str]] = None,
                 extra_configuration: Optional[pulumi.Input['ServiceMeshExtraConfigurationArgs']] = None,
                 force: Optional[pulumi.Input[builtins.bool]] = None,
                 load_balancer: Optional[pulumi.Input['ServiceMeshLoadBalancerArgs']] = None,
                 mesh_config: Optional[pulumi.Input['ServiceMeshMeshConfigArgs']] = None,
                 prometheus_url: Optional[pulumi.Input[builtins.str]] = None,
                 service_mesh_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 version: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a ServiceMesh resource.
        :param pulumi.Input['ServiceMeshNetworkArgs'] network: Service grid network configuration information See `network` below.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] cluster_ids: List of clusters.
        :param pulumi.Input[builtins.str] cluster_spec: Cluster specification
        :param pulumi.Input[builtins.bool] customized_prometheus: Whether to customize Prometheus. Value:
               -'true': custom Prometheus.
               -'false': Do not customize Prometheus.
               
               Default value: 'false '.
        :param pulumi.Input[builtins.str] edition: Grid instance version type (for example: the standard, the Pro version, etc.)
        :param pulumi.Input['ServiceMeshExtraConfigurationArgs'] extra_configuration: Data plane KubeAPI access capability See `extra_configuration` below.
        :param pulumi.Input[builtins.bool] force: Whether to forcibly delete the ASM instance. Value:
               -'true': force deletion of ASM instance
               -'false': no forced deletion of ASM instance
               
               Default value: false
        :param pulumi.Input['ServiceMeshLoadBalancerArgs'] load_balancer: Load balancing information See `load_balancer` below.
        :param pulumi.Input['ServiceMeshMeshConfigArgs'] mesh_config: Service grid configuration information See `mesh_config` below.
        :param pulumi.Input[builtins.str] prometheus_url: The Prometheus service address (in non-custom cases, use the ARMS address format).
        :param pulumi.Input[builtins.str] service_mesh_name: ServiceMeshName
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The tag of the resource
        :param pulumi.Input[builtins.str] version: Service grid version number
        """
        pulumi.set(__self__, "network", network)
        if cluster_ids is not None:
            pulumi.set(__self__, "cluster_ids", cluster_ids)
        if cluster_spec is not None:
            pulumi.set(__self__, "cluster_spec", cluster_spec)
        if customized_prometheus is not None:
            pulumi.set(__self__, "customized_prometheus", customized_prometheus)
        if edition is not None:
            pulumi.set(__self__, "edition", edition)
        if extra_configuration is not None:
            pulumi.set(__self__, "extra_configuration", extra_configuration)
        if force is not None:
            pulumi.set(__self__, "force", force)
        if load_balancer is not None:
            pulumi.set(__self__, "load_balancer", load_balancer)
        if mesh_config is not None:
            pulumi.set(__self__, "mesh_config", mesh_config)
        if prometheus_url is not None:
            pulumi.set(__self__, "prometheus_url", prometheus_url)
        if service_mesh_name is not None:
            pulumi.set(__self__, "service_mesh_name", service_mesh_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter
    def network(self) -> pulumi.Input['ServiceMeshNetworkArgs']:
        """
        Service grid network configuration information See `network` below.
        """
        return pulumi.get(self, "network")

    @network.setter
    def network(self, value: pulumi.Input['ServiceMeshNetworkArgs']):
        pulumi.set(self, "network", value)

    @property
    @pulumi.getter(name="clusterIds")
    def cluster_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of clusters.
        """
        return pulumi.get(self, "cluster_ids")

    @cluster_ids.setter
    def cluster_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "cluster_ids", value)

    @property
    @pulumi.getter(name="clusterSpec")
    def cluster_spec(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Cluster specification
        """
        return pulumi.get(self, "cluster_spec")

    @cluster_spec.setter
    def cluster_spec(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cluster_spec", value)

    @property
    @pulumi.getter(name="customizedPrometheus")
    def customized_prometheus(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to customize Prometheus. Value:
        -'true': custom Prometheus.
        -'false': Do not customize Prometheus.

        Default value: 'false '.
        """
        return pulumi.get(self, "customized_prometheus")

    @customized_prometheus.setter
    def customized_prometheus(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "customized_prometheus", value)

    @property
    @pulumi.getter
    def edition(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Grid instance version type (for example: the standard, the Pro version, etc.)
        """
        return pulumi.get(self, "edition")

    @edition.setter
    def edition(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "edition", value)

    @property
    @pulumi.getter(name="extraConfiguration")
    def extra_configuration(self) -> Optional[pulumi.Input['ServiceMeshExtraConfigurationArgs']]:
        """
        Data plane KubeAPI access capability See `extra_configuration` below.
        """
        return pulumi.get(self, "extra_configuration")

    @extra_configuration.setter
    def extra_configuration(self, value: Optional[pulumi.Input['ServiceMeshExtraConfigurationArgs']]):
        pulumi.set(self, "extra_configuration", value)

    @property
    @pulumi.getter
    def force(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to forcibly delete the ASM instance. Value:
        -'true': force deletion of ASM instance
        -'false': no forced deletion of ASM instance

        Default value: false
        """
        return pulumi.get(self, "force")

    @force.setter
    def force(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "force", value)

    @property
    @pulumi.getter(name="loadBalancer")
    def load_balancer(self) -> Optional[pulumi.Input['ServiceMeshLoadBalancerArgs']]:
        """
        Load balancing information See `load_balancer` below.
        """
        return pulumi.get(self, "load_balancer")

    @load_balancer.setter
    def load_balancer(self, value: Optional[pulumi.Input['ServiceMeshLoadBalancerArgs']]):
        pulumi.set(self, "load_balancer", value)

    @property
    @pulumi.getter(name="meshConfig")
    def mesh_config(self) -> Optional[pulumi.Input['ServiceMeshMeshConfigArgs']]:
        """
        Service grid configuration information See `mesh_config` below.
        """
        return pulumi.get(self, "mesh_config")

    @mesh_config.setter
    def mesh_config(self, value: Optional[pulumi.Input['ServiceMeshMeshConfigArgs']]):
        pulumi.set(self, "mesh_config", value)

    @property
    @pulumi.getter(name="prometheusUrl")
    def prometheus_url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The Prometheus service address (in non-custom cases, use the ARMS address format).
        """
        return pulumi.get(self, "prometheus_url")

    @prometheus_url.setter
    def prometheus_url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "prometheus_url", value)

    @property
    @pulumi.getter(name="serviceMeshName")
    def service_mesh_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ServiceMeshName
        """
        return pulumi.get(self, "service_mesh_name")

    @service_mesh_name.setter
    def service_mesh_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_mesh_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        The tag of the resource
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Service grid version number
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "version", value)


@pulumi.input_type
class _ServiceMeshState:
    def __init__(__self__, *,
                 cluster_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 cluster_spec: Optional[pulumi.Input[builtins.str]] = None,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 customized_prometheus: Optional[pulumi.Input[builtins.bool]] = None,
                 edition: Optional[pulumi.Input[builtins.str]] = None,
                 extra_configuration: Optional[pulumi.Input['ServiceMeshExtraConfigurationArgs']] = None,
                 force: Optional[pulumi.Input[builtins.bool]] = None,
                 kubeconfig: Optional[pulumi.Input[builtins.str]] = None,
                 load_balancer: Optional[pulumi.Input['ServiceMeshLoadBalancerArgs']] = None,
                 mesh_config: Optional[pulumi.Input['ServiceMeshMeshConfigArgs']] = None,
                 network: Optional[pulumi.Input['ServiceMeshNetworkArgs']] = None,
                 prometheus_url: Optional[pulumi.Input[builtins.str]] = None,
                 service_mesh_name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 version: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering ServiceMesh resources.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] cluster_ids: List of clusters.
        :param pulumi.Input[builtins.str] cluster_spec: Cluster specification
        :param pulumi.Input[builtins.str] create_time: Service grid creation time
        :param pulumi.Input[builtins.bool] customized_prometheus: Whether to customize Prometheus. Value:
               -'true': custom Prometheus.
               -'false': Do not customize Prometheus.
               
               Default value: 'false '.
        :param pulumi.Input[builtins.str] edition: Grid instance version type (for example: the standard, the Pro version, etc.)
        :param pulumi.Input['ServiceMeshExtraConfigurationArgs'] extra_configuration: Data plane KubeAPI access capability See `extra_configuration` below.
        :param pulumi.Input[builtins.bool] force: Whether to forcibly delete the ASM instance. Value:
               -'true': force deletion of ASM instance
               -'false': no forced deletion of ASM instance
               
               Default value: false
        :param pulumi.Input[builtins.str] kubeconfig: Kubeconfig configuration content
        :param pulumi.Input['ServiceMeshLoadBalancerArgs'] load_balancer: Load balancing information See `load_balancer` below.
        :param pulumi.Input['ServiceMeshMeshConfigArgs'] mesh_config: Service grid configuration information See `mesh_config` below.
        :param pulumi.Input['ServiceMeshNetworkArgs'] network: Service grid network configuration information See `network` below.
        :param pulumi.Input[builtins.str] prometheus_url: The Prometheus service address (in non-custom cases, use the ARMS address format).
        :param pulumi.Input[builtins.str] service_mesh_name: ServiceMeshName
        :param pulumi.Input[builtins.str] status: The status of the resource
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The tag of the resource
        :param pulumi.Input[builtins.str] version: Service grid version number
        """
        if cluster_ids is not None:
            pulumi.set(__self__, "cluster_ids", cluster_ids)
        if cluster_spec is not None:
            pulumi.set(__self__, "cluster_spec", cluster_spec)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if customized_prometheus is not None:
            pulumi.set(__self__, "customized_prometheus", customized_prometheus)
        if edition is not None:
            pulumi.set(__self__, "edition", edition)
        if extra_configuration is not None:
            pulumi.set(__self__, "extra_configuration", extra_configuration)
        if force is not None:
            pulumi.set(__self__, "force", force)
        if kubeconfig is not None:
            pulumi.set(__self__, "kubeconfig", kubeconfig)
        if load_balancer is not None:
            pulumi.set(__self__, "load_balancer", load_balancer)
        if mesh_config is not None:
            pulumi.set(__self__, "mesh_config", mesh_config)
        if network is not None:
            pulumi.set(__self__, "network", network)
        if prometheus_url is not None:
            pulumi.set(__self__, "prometheus_url", prometheus_url)
        if service_mesh_name is not None:
            pulumi.set(__self__, "service_mesh_name", service_mesh_name)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter(name="clusterIds")
    def cluster_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of clusters.
        """
        return pulumi.get(self, "cluster_ids")

    @cluster_ids.setter
    def cluster_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "cluster_ids", value)

    @property
    @pulumi.getter(name="clusterSpec")
    def cluster_spec(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Cluster specification
        """
        return pulumi.get(self, "cluster_spec")

    @cluster_spec.setter
    def cluster_spec(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cluster_spec", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Service grid creation time
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="customizedPrometheus")
    def customized_prometheus(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to customize Prometheus. Value:
        -'true': custom Prometheus.
        -'false': Do not customize Prometheus.

        Default value: 'false '.
        """
        return pulumi.get(self, "customized_prometheus")

    @customized_prometheus.setter
    def customized_prometheus(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "customized_prometheus", value)

    @property
    @pulumi.getter
    def edition(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Grid instance version type (for example: the standard, the Pro version, etc.)
        """
        return pulumi.get(self, "edition")

    @edition.setter
    def edition(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "edition", value)

    @property
    @pulumi.getter(name="extraConfiguration")
    def extra_configuration(self) -> Optional[pulumi.Input['ServiceMeshExtraConfigurationArgs']]:
        """
        Data plane KubeAPI access capability See `extra_configuration` below.
        """
        return pulumi.get(self, "extra_configuration")

    @extra_configuration.setter
    def extra_configuration(self, value: Optional[pulumi.Input['ServiceMeshExtraConfigurationArgs']]):
        pulumi.set(self, "extra_configuration", value)

    @property
    @pulumi.getter
    def force(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to forcibly delete the ASM instance. Value:
        -'true': force deletion of ASM instance
        -'false': no forced deletion of ASM instance

        Default value: false
        """
        return pulumi.get(self, "force")

    @force.setter
    def force(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "force", value)

    @property
    @pulumi.getter
    def kubeconfig(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Kubeconfig configuration content
        """
        return pulumi.get(self, "kubeconfig")

    @kubeconfig.setter
    def kubeconfig(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kubeconfig", value)

    @property
    @pulumi.getter(name="loadBalancer")
    def load_balancer(self) -> Optional[pulumi.Input['ServiceMeshLoadBalancerArgs']]:
        """
        Load balancing information See `load_balancer` below.
        """
        return pulumi.get(self, "load_balancer")

    @load_balancer.setter
    def load_balancer(self, value: Optional[pulumi.Input['ServiceMeshLoadBalancerArgs']]):
        pulumi.set(self, "load_balancer", value)

    @property
    @pulumi.getter(name="meshConfig")
    def mesh_config(self) -> Optional[pulumi.Input['ServiceMeshMeshConfigArgs']]:
        """
        Service grid configuration information See `mesh_config` below.
        """
        return pulumi.get(self, "mesh_config")

    @mesh_config.setter
    def mesh_config(self, value: Optional[pulumi.Input['ServiceMeshMeshConfigArgs']]):
        pulumi.set(self, "mesh_config", value)

    @property
    @pulumi.getter
    def network(self) -> Optional[pulumi.Input['ServiceMeshNetworkArgs']]:
        """
        Service grid network configuration information See `network` below.
        """
        return pulumi.get(self, "network")

    @network.setter
    def network(self, value: Optional[pulumi.Input['ServiceMeshNetworkArgs']]):
        pulumi.set(self, "network", value)

    @property
    @pulumi.getter(name="prometheusUrl")
    def prometheus_url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The Prometheus service address (in non-custom cases, use the ARMS address format).
        """
        return pulumi.get(self, "prometheus_url")

    @prometheus_url.setter
    def prometheus_url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "prometheus_url", value)

    @property
    @pulumi.getter(name="serviceMeshName")
    def service_mesh_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ServiceMeshName
        """
        return pulumi.get(self, "service_mesh_name")

    @service_mesh_name.setter
    def service_mesh_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_mesh_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        The tag of the resource
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Service grid version number
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "version", value)


@pulumi.type_token("alicloud:servicemesh/serviceMesh:ServiceMesh")
class ServiceMesh(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 cluster_spec: Optional[pulumi.Input[builtins.str]] = None,
                 customized_prometheus: Optional[pulumi.Input[builtins.bool]] = None,
                 edition: Optional[pulumi.Input[builtins.str]] = None,
                 extra_configuration: Optional[pulumi.Input[Union['ServiceMeshExtraConfigurationArgs', 'ServiceMeshExtraConfigurationArgsDict']]] = None,
                 force: Optional[pulumi.Input[builtins.bool]] = None,
                 load_balancer: Optional[pulumi.Input[Union['ServiceMeshLoadBalancerArgs', 'ServiceMeshLoadBalancerArgsDict']]] = None,
                 mesh_config: Optional[pulumi.Input[Union['ServiceMeshMeshConfigArgs', 'ServiceMeshMeshConfigArgsDict']]] = None,
                 network: Optional[pulumi.Input[Union['ServiceMeshNetworkArgs', 'ServiceMeshNetworkArgsDict']]] = None,
                 prometheus_url: Optional[pulumi.Input[builtins.str]] = None,
                 service_mesh_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 version: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a Service Mesh Service Mesh resource.

        For information about Service Mesh Service Mesh and how to use it, see [What is Service Mesh](https://www.alibabacloud.com/help/en/asm/developer-reference/api-servicemesh-2020-01-11-createservicemesh).

        > **NOTE:** Available since v1.138.0.

        ## Import

        Service Mesh Service Mesh can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:servicemesh/serviceMesh:ServiceMesh example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] cluster_ids: List of clusters.
        :param pulumi.Input[builtins.str] cluster_spec: Cluster specification
        :param pulumi.Input[builtins.bool] customized_prometheus: Whether to customize Prometheus. Value:
               -'true': custom Prometheus.
               -'false': Do not customize Prometheus.
               
               Default value: 'false '.
        :param pulumi.Input[builtins.str] edition: Grid instance version type (for example: the standard, the Pro version, etc.)
        :param pulumi.Input[Union['ServiceMeshExtraConfigurationArgs', 'ServiceMeshExtraConfigurationArgsDict']] extra_configuration: Data plane KubeAPI access capability See `extra_configuration` below.
        :param pulumi.Input[builtins.bool] force: Whether to forcibly delete the ASM instance. Value:
               -'true': force deletion of ASM instance
               -'false': no forced deletion of ASM instance
               
               Default value: false
        :param pulumi.Input[Union['ServiceMeshLoadBalancerArgs', 'ServiceMeshLoadBalancerArgsDict']] load_balancer: Load balancing information See `load_balancer` below.
        :param pulumi.Input[Union['ServiceMeshMeshConfigArgs', 'ServiceMeshMeshConfigArgsDict']] mesh_config: Service grid configuration information See `mesh_config` below.
        :param pulumi.Input[Union['ServiceMeshNetworkArgs', 'ServiceMeshNetworkArgsDict']] network: Service grid network configuration information See `network` below.
        :param pulumi.Input[builtins.str] prometheus_url: The Prometheus service address (in non-custom cases, use the ARMS address format).
        :param pulumi.Input[builtins.str] service_mesh_name: ServiceMeshName
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The tag of the resource
        :param pulumi.Input[builtins.str] version: Service grid version number
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ServiceMeshArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Service Mesh Service Mesh resource.

        For information about Service Mesh Service Mesh and how to use it, see [What is Service Mesh](https://www.alibabacloud.com/help/en/asm/developer-reference/api-servicemesh-2020-01-11-createservicemesh).

        > **NOTE:** Available since v1.138.0.

        ## Import

        Service Mesh Service Mesh can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:servicemesh/serviceMesh:ServiceMesh example <id>
        ```

        :param str resource_name: The name of the resource.
        :param ServiceMeshArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ServiceMeshArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 cluster_spec: Optional[pulumi.Input[builtins.str]] = None,
                 customized_prometheus: Optional[pulumi.Input[builtins.bool]] = None,
                 edition: Optional[pulumi.Input[builtins.str]] = None,
                 extra_configuration: Optional[pulumi.Input[Union['ServiceMeshExtraConfigurationArgs', 'ServiceMeshExtraConfigurationArgsDict']]] = None,
                 force: Optional[pulumi.Input[builtins.bool]] = None,
                 load_balancer: Optional[pulumi.Input[Union['ServiceMeshLoadBalancerArgs', 'ServiceMeshLoadBalancerArgsDict']]] = None,
                 mesh_config: Optional[pulumi.Input[Union['ServiceMeshMeshConfigArgs', 'ServiceMeshMeshConfigArgsDict']]] = None,
                 network: Optional[pulumi.Input[Union['ServiceMeshNetworkArgs', 'ServiceMeshNetworkArgsDict']]] = None,
                 prometheus_url: Optional[pulumi.Input[builtins.str]] = None,
                 service_mesh_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 version: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ServiceMeshArgs.__new__(ServiceMeshArgs)

            __props__.__dict__["cluster_ids"] = cluster_ids
            __props__.__dict__["cluster_spec"] = cluster_spec
            __props__.__dict__["customized_prometheus"] = customized_prometheus
            __props__.__dict__["edition"] = edition
            __props__.__dict__["extra_configuration"] = extra_configuration
            __props__.__dict__["force"] = force
            __props__.__dict__["load_balancer"] = load_balancer
            __props__.__dict__["mesh_config"] = mesh_config
            if network is None and not opts.urn:
                raise TypeError("Missing required property 'network'")
            __props__.__dict__["network"] = network
            __props__.__dict__["prometheus_url"] = prometheus_url
            __props__.__dict__["service_mesh_name"] = service_mesh_name
            __props__.__dict__["tags"] = tags
            __props__.__dict__["version"] = version
            __props__.__dict__["create_time"] = None
            __props__.__dict__["kubeconfig"] = None
            __props__.__dict__["status"] = None
        super(ServiceMesh, __self__).__init__(
            'alicloud:servicemesh/serviceMesh:ServiceMesh',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cluster_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            cluster_spec: Optional[pulumi.Input[builtins.str]] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            customized_prometheus: Optional[pulumi.Input[builtins.bool]] = None,
            edition: Optional[pulumi.Input[builtins.str]] = None,
            extra_configuration: Optional[pulumi.Input[Union['ServiceMeshExtraConfigurationArgs', 'ServiceMeshExtraConfigurationArgsDict']]] = None,
            force: Optional[pulumi.Input[builtins.bool]] = None,
            kubeconfig: Optional[pulumi.Input[builtins.str]] = None,
            load_balancer: Optional[pulumi.Input[Union['ServiceMeshLoadBalancerArgs', 'ServiceMeshLoadBalancerArgsDict']]] = None,
            mesh_config: Optional[pulumi.Input[Union['ServiceMeshMeshConfigArgs', 'ServiceMeshMeshConfigArgsDict']]] = None,
            network: Optional[pulumi.Input[Union['ServiceMeshNetworkArgs', 'ServiceMeshNetworkArgsDict']]] = None,
            prometheus_url: Optional[pulumi.Input[builtins.str]] = None,
            service_mesh_name: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
            version: Optional[pulumi.Input[builtins.str]] = None) -> 'ServiceMesh':
        """
        Get an existing ServiceMesh resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] cluster_ids: List of clusters.
        :param pulumi.Input[builtins.str] cluster_spec: Cluster specification
        :param pulumi.Input[builtins.str] create_time: Service grid creation time
        :param pulumi.Input[builtins.bool] customized_prometheus: Whether to customize Prometheus. Value:
               -'true': custom Prometheus.
               -'false': Do not customize Prometheus.
               
               Default value: 'false '.
        :param pulumi.Input[builtins.str] edition: Grid instance version type (for example: the standard, the Pro version, etc.)
        :param pulumi.Input[Union['ServiceMeshExtraConfigurationArgs', 'ServiceMeshExtraConfigurationArgsDict']] extra_configuration: Data plane KubeAPI access capability See `extra_configuration` below.
        :param pulumi.Input[builtins.bool] force: Whether to forcibly delete the ASM instance. Value:
               -'true': force deletion of ASM instance
               -'false': no forced deletion of ASM instance
               
               Default value: false
        :param pulumi.Input[builtins.str] kubeconfig: Kubeconfig configuration content
        :param pulumi.Input[Union['ServiceMeshLoadBalancerArgs', 'ServiceMeshLoadBalancerArgsDict']] load_balancer: Load balancing information See `load_balancer` below.
        :param pulumi.Input[Union['ServiceMeshMeshConfigArgs', 'ServiceMeshMeshConfigArgsDict']] mesh_config: Service grid configuration information See `mesh_config` below.
        :param pulumi.Input[Union['ServiceMeshNetworkArgs', 'ServiceMeshNetworkArgsDict']] network: Service grid network configuration information See `network` below.
        :param pulumi.Input[builtins.str] prometheus_url: The Prometheus service address (in non-custom cases, use the ARMS address format).
        :param pulumi.Input[builtins.str] service_mesh_name: ServiceMeshName
        :param pulumi.Input[builtins.str] status: The status of the resource
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The tag of the resource
        :param pulumi.Input[builtins.str] version: Service grid version number
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ServiceMeshState.__new__(_ServiceMeshState)

        __props__.__dict__["cluster_ids"] = cluster_ids
        __props__.__dict__["cluster_spec"] = cluster_spec
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["customized_prometheus"] = customized_prometheus
        __props__.__dict__["edition"] = edition
        __props__.__dict__["extra_configuration"] = extra_configuration
        __props__.__dict__["force"] = force
        __props__.__dict__["kubeconfig"] = kubeconfig
        __props__.__dict__["load_balancer"] = load_balancer
        __props__.__dict__["mesh_config"] = mesh_config
        __props__.__dict__["network"] = network
        __props__.__dict__["prometheus_url"] = prometheus_url
        __props__.__dict__["service_mesh_name"] = service_mesh_name
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["version"] = version
        return ServiceMesh(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="clusterIds")
    def cluster_ids(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        List of clusters.
        """
        return pulumi.get(self, "cluster_ids")

    @property
    @pulumi.getter(name="clusterSpec")
    def cluster_spec(self) -> pulumi.Output[builtins.str]:
        """
        Cluster specification
        """
        return pulumi.get(self, "cluster_spec")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        Service grid creation time
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="customizedPrometheus")
    def customized_prometheus(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Whether to customize Prometheus. Value:
        -'true': custom Prometheus.
        -'false': Do not customize Prometheus.

        Default value: 'false '.
        """
        return pulumi.get(self, "customized_prometheus")

    @property
    @pulumi.getter
    def edition(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Grid instance version type (for example: the standard, the Pro version, etc.)
        """
        return pulumi.get(self, "edition")

    @property
    @pulumi.getter(name="extraConfiguration")
    def extra_configuration(self) -> pulumi.Output['outputs.ServiceMeshExtraConfiguration']:
        """
        Data plane KubeAPI access capability See `extra_configuration` below.
        """
        return pulumi.get(self, "extra_configuration")

    @property
    @pulumi.getter
    def force(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Whether to forcibly delete the ASM instance. Value:
        -'true': force deletion of ASM instance
        -'false': no forced deletion of ASM instance

        Default value: false
        """
        return pulumi.get(self, "force")

    @property
    @pulumi.getter
    def kubeconfig(self) -> pulumi.Output[builtins.str]:
        """
        Kubeconfig configuration content
        """
        return pulumi.get(self, "kubeconfig")

    @property
    @pulumi.getter(name="loadBalancer")
    def load_balancer(self) -> pulumi.Output['outputs.ServiceMeshLoadBalancer']:
        """
        Load balancing information See `load_balancer` below.
        """
        return pulumi.get(self, "load_balancer")

    @property
    @pulumi.getter(name="meshConfig")
    def mesh_config(self) -> pulumi.Output['outputs.ServiceMeshMeshConfig']:
        """
        Service grid configuration information See `mesh_config` below.
        """
        return pulumi.get(self, "mesh_config")

    @property
    @pulumi.getter
    def network(self) -> pulumi.Output['outputs.ServiceMeshNetwork']:
        """
        Service grid network configuration information See `network` below.
        """
        return pulumi.get(self, "network")

    @property
    @pulumi.getter(name="prometheusUrl")
    def prometheus_url(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The Prometheus service address (in non-custom cases, use the ARMS address format).
        """
        return pulumi.get(self, "prometheus_url")

    @property
    @pulumi.getter(name="serviceMeshName")
    def service_mesh_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        ServiceMeshName
        """
        return pulumi.get(self, "service_mesh_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, builtins.str]]]:
        """
        The tag of the resource
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def version(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Service grid version number
        """
        return pulumi.get(self, "version")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetDBClusterLakeVersionsResult',
    'AwaitableGetDBClusterLakeVersionsResult',
    'get_db_cluster_lake_versions',
    'get_db_cluster_lake_versions_output',
]

@pulumi.output_type
class GetDBClusterLakeVersionsResult:
    """
    A collection of values returned by getDBClusterLakeVersions.
    """
    def __init__(__self__, enable_details=None, id=None, ids=None, output_file=None, page_number=None, page_size=None, resource_group_id=None, status=None, versions=None):
        if enable_details and not isinstance(enable_details, bool):
            raise TypeError("Expected argument 'enable_details' to be a bool")
        pulumi.set(__self__, "enable_details", enable_details)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if page_number and not isinstance(page_number, int):
            raise TypeError("Expected argument 'page_number' to be a int")
        pulumi.set(__self__, "page_number", page_number)
        if page_size and not isinstance(page_size, int):
            raise TypeError("Expected argument 'page_size' to be a int")
        pulumi.set(__self__, "page_size", page_size)
        if resource_group_id and not isinstance(resource_group_id, str):
            raise TypeError("Expected argument 'resource_group_id' to be a str")
        pulumi.set(__self__, "resource_group_id", resource_group_id)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if versions and not isinstance(versions, list):
            raise TypeError("Expected argument 'versions' to be a list")
        pulumi.set(__self__, "versions", versions)

    @property
    @pulumi.getter(name="enableDetails")
    def enable_details(self) -> Optional[builtins.bool]:
        return pulumi.get(self, "enable_details")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[builtins.str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="pageNumber")
    def page_number(self) -> Optional[builtins.int]:
        return pulumi.get(self, "page_number")

    @property
    @pulumi.getter(name="pageSize")
    def page_size(self) -> Optional[builtins.int]:
        return pulumi.get(self, "page_size")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[builtins.str]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter
    def status(self) -> Optional[builtins.str]:
        """
        The status of the resource.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def versions(self) -> Sequence['outputs.GetDBClusterLakeVersionsVersionResult']:
        """
        A list of Adb Db Clusters. Each element contains the following attributes:
        """
        return pulumi.get(self, "versions")


class AwaitableGetDBClusterLakeVersionsResult(GetDBClusterLakeVersionsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDBClusterLakeVersionsResult(
            enable_details=self.enable_details,
            id=self.id,
            ids=self.ids,
            output_file=self.output_file,
            page_number=self.page_number,
            page_size=self.page_size,
            resource_group_id=self.resource_group_id,
            status=self.status,
            versions=self.versions)


def get_db_cluster_lake_versions(enable_details: Optional[builtins.bool] = None,
                                 ids: Optional[Sequence[builtins.str]] = None,
                                 output_file: Optional[builtins.str] = None,
                                 page_number: Optional[builtins.int] = None,
                                 page_size: Optional[builtins.int] = None,
                                 resource_group_id: Optional[builtins.str] = None,
                                 status: Optional[builtins.str] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDBClusterLakeVersionsResult:
    """
    This data source provides the Adb DBCluster Lake Versions of the current Alibaba Cloud user.

    > **NOTE:** Available since v1.190.0.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.adb.get_zones()
    default_get_networks = alicloud.vpc.get_networks(name_regex="^default-NODELETING$")
    default_get_switches = alicloud.vpc.get_switches(vpc_id=default_get_networks.ids[0],
        zone_id=default.ids[0])
    default_db_cluster_lake_version = alicloud.adb.DBClusterLakeVersion("default",
        db_cluster_version="5.0",
        vpc_id=default_get_networks.ids[0],
        vswitch_id=default_get_switches.ids[0],
        zone_id=default.ids[0],
        compute_resource="16ACU",
        storage_resource="0ACU",
        payment_type="PayAsYouGo",
        enable_default_resource_group=False)
    ids = alicloud.adb.get_db_cluster_lake_versions_output(ids=[default_db_cluster_lake_version.id])
    pulumi.export("adbDbClusterLakeVersionId1", ids.versions[0].id)
    ```


    :param builtins.bool enable_details: Default to `false`. Set it to `true` can output more details about resource attributes.
    :param Sequence[builtins.str] ids: A list of DBCluster IDs.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str resource_group_id: The ID of the resource group.
    :param builtins.str status: The status of the resource. Valid values: `Preparing`, `Creating`, `Restoring`, `Running`, `Deleting`, `ClassChanging`, `NetAddressCreating`, `NetAddressDeleting`.
    """
    __args__ = dict()
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['pageNumber'] = page_number
    __args__['pageSize'] = page_size
    __args__['resourceGroupId'] = resource_group_id
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:adb/getDBClusterLakeVersions:getDBClusterLakeVersions', __args__, opts=opts, typ=GetDBClusterLakeVersionsResult).value

    return AwaitableGetDBClusterLakeVersionsResult(
        enable_details=pulumi.get(__ret__, 'enable_details'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        output_file=pulumi.get(__ret__, 'output_file'),
        page_number=pulumi.get(__ret__, 'page_number'),
        page_size=pulumi.get(__ret__, 'page_size'),
        resource_group_id=pulumi.get(__ret__, 'resource_group_id'),
        status=pulumi.get(__ret__, 'status'),
        versions=pulumi.get(__ret__, 'versions'))
def get_db_cluster_lake_versions_output(enable_details: Optional[pulumi.Input[Optional[builtins.bool]]] = None,
                                        ids: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                                        output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                        page_number: Optional[pulumi.Input[Optional[builtins.int]]] = None,
                                        page_size: Optional[pulumi.Input[Optional[builtins.int]]] = None,
                                        resource_group_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                        status: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDBClusterLakeVersionsResult]:
    """
    This data source provides the Adb DBCluster Lake Versions of the current Alibaba Cloud user.

    > **NOTE:** Available since v1.190.0.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.adb.get_zones()
    default_get_networks = alicloud.vpc.get_networks(name_regex="^default-NODELETING$")
    default_get_switches = alicloud.vpc.get_switches(vpc_id=default_get_networks.ids[0],
        zone_id=default.ids[0])
    default_db_cluster_lake_version = alicloud.adb.DBClusterLakeVersion("default",
        db_cluster_version="5.0",
        vpc_id=default_get_networks.ids[0],
        vswitch_id=default_get_switches.ids[0],
        zone_id=default.ids[0],
        compute_resource="16ACU",
        storage_resource="0ACU",
        payment_type="PayAsYouGo",
        enable_default_resource_group=False)
    ids = alicloud.adb.get_db_cluster_lake_versions_output(ids=[default_db_cluster_lake_version.id])
    pulumi.export("adbDbClusterLakeVersionId1", ids.versions[0].id)
    ```


    :param builtins.bool enable_details: Default to `false`. Set it to `true` can output more details about resource attributes.
    :param Sequence[builtins.str] ids: A list of DBCluster IDs.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str resource_group_id: The ID of the resource group.
    :param builtins.str status: The status of the resource. Valid values: `Preparing`, `Creating`, `Restoring`, `Running`, `Deleting`, `ClassChanging`, `NetAddressCreating`, `NetAddressDeleting`.
    """
    __args__ = dict()
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['pageNumber'] = page_number
    __args__['pageSize'] = page_size
    __args__['resourceGroupId'] = resource_group_id
    __args__['status'] = status
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:adb/getDBClusterLakeVersions:getDBClusterLakeVersions', __args__, opts=opts, typ=GetDBClusterLakeVersionsResult)
    return __ret__.apply(lambda __response__: GetDBClusterLakeVersionsResult(
        enable_details=pulumi.get(__response__, 'enable_details'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        output_file=pulumi.get(__response__, 'output_file'),
        page_number=pulumi.get(__response__, 'page_number'),
        page_size=pulumi.get(__response__, 'page_size'),
        resource_group_id=pulumi.get(__response__, 'resource_group_id'),
        status=pulumi.get(__response__, 'status'),
        versions=pulumi.get(__response__, 'versions')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetPricesResult',
    'AwaitableGetPricesResult',
    'get_prices',
    'get_prices_output',
]

@pulumi.output_type
class GetPricesResult:
    """
    A collection of values returned by getPrices.
    """
    def __init__(__self__, desire_attributes=None, id=None, output_file=None, prices=None, product=None, resource_code=None):
        if desire_attributes and not isinstance(desire_attributes, dict):
            raise TypeError("Expected argument 'desire_attributes' to be a dict")
        pulumi.set(__self__, "desire_attributes", desire_attributes)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if prices and not isinstance(prices, list):
            raise TypeError("Expected argument 'prices' to be a list")
        pulumi.set(__self__, "prices", prices)
        if product and not isinstance(product, str):
            raise TypeError("Expected argument 'product' to be a str")
        pulumi.set(__self__, "product", product)
        if resource_code and not isinstance(resource_code, str):
            raise TypeError("Expected argument 'resource_code' to be a str")
        pulumi.set(__self__, "resource_code", resource_code)

    @property
    @pulumi.getter(name="desireAttributes")
    def desire_attributes(self) -> Optional[Mapping[str, builtins.str]]:
        return pulumi.get(self, "desire_attributes")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def prices(self) -> Sequence['outputs.GetPricesPriceResult']:
        """
        A list of Price Entries. Each element contains the following attributes:
        """
        return pulumi.get(self, "prices")

    @property
    @pulumi.getter
    def product(self) -> builtins.str:
        return pulumi.get(self, "product")

    @property
    @pulumi.getter(name="resourceCode")
    def resource_code(self) -> builtins.str:
        return pulumi.get(self, "resource_code")


class AwaitableGetPricesResult(GetPricesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPricesResult(
            desire_attributes=self.desire_attributes,
            id=self.id,
            output_file=self.output_file,
            prices=self.prices,
            product=self.product,
            resource_code=self.resource_code)


def get_prices(desire_attributes: Optional[Mapping[str, builtins.str]] = None,
               output_file: Optional[builtins.str] = None,
               product: Optional[builtins.str] = None,
               resource_code: Optional[builtins.str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPricesResult:
    """
    This data source provides Cloud Control Price available to the user.[What is Price](https://next.api.aliyun.com/document/cloudcontrol/2022-08-30/GetPrice)

    > **NOTE:** Available since v1.241.0.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "terraform-example"
    default = alicloud.cloudcontrol.get_prices(desire_attributes={
            "AddressType": "internet",
            "PaymentType": "PayAsYouGo",
        },
        product="SLB",
        resource_code="LoadBalancer")
    pulumi.export("alicloudCloudControlPriceExampleId", default.prices[0].discount_price)
    ```


    :param Mapping[str, builtins.str] desire_attributes: This property represent the detailed configuration of the Resource which you are going to get price.  Give same content as DesireAttributes of the 'Resource' Resource when start Create operation. 'PaymentType' is necessary when in DesireAttributes.  Here is a probably example when you get the price of SLB LoadBalancer:```json{"LoadBalancerName": "cc-test","Bandwidth": 6,"PaymentType": "PayAsYouGo","AddressType": "internet","LoadBalancerSpec": "slb.s3.small","InternetChargeType": "paybybandwidth"} See `DesireAttributes` below.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str product: The product Code represents the product to be operated. Currently supported products and resources can be queried at the following link: [supported-services-and-resource-types](https://help.aliyun.com/zh/cloud-control-api/product-overview/supported-services-and-resource-types).
    :param builtins.str resource_code: Resource Code, if there is a parent resource, split with `::`, such as VPC::VSwitch. The supported resource Code can be obtained from the following link: [supported-services-and-resource-types](https://help.aliyun.com/zh/cloud-control-api/product-overview/supported-services-and-resource-types).
    """
    __args__ = dict()
    __args__['desireAttributes'] = desire_attributes
    __args__['outputFile'] = output_file
    __args__['product'] = product
    __args__['resourceCode'] = resource_code
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:cloudcontrol/getPrices:getPrices', __args__, opts=opts, typ=GetPricesResult).value

    return AwaitableGetPricesResult(
        desire_attributes=pulumi.get(__ret__, 'desire_attributes'),
        id=pulumi.get(__ret__, 'id'),
        output_file=pulumi.get(__ret__, 'output_file'),
        prices=pulumi.get(__ret__, 'prices'),
        product=pulumi.get(__ret__, 'product'),
        resource_code=pulumi.get(__ret__, 'resource_code'))
def get_prices_output(desire_attributes: Optional[pulumi.Input[Optional[Mapping[str, builtins.str]]]] = None,
                      output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                      product: Optional[pulumi.Input[builtins.str]] = None,
                      resource_code: Optional[pulumi.Input[builtins.str]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPricesResult]:
    """
    This data source provides Cloud Control Price available to the user.[What is Price](https://next.api.aliyun.com/document/cloudcontrol/2022-08-30/GetPrice)

    > **NOTE:** Available since v1.241.0.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "terraform-example"
    default = alicloud.cloudcontrol.get_prices(desire_attributes={
            "AddressType": "internet",
            "PaymentType": "PayAsYouGo",
        },
        product="SLB",
        resource_code="LoadBalancer")
    pulumi.export("alicloudCloudControlPriceExampleId", default.prices[0].discount_price)
    ```


    :param Mapping[str, builtins.str] desire_attributes: This property represent the detailed configuration of the Resource which you are going to get price.  Give same content as DesireAttributes of the 'Resource' Resource when start Create operation. 'PaymentType' is necessary when in DesireAttributes.  Here is a probably example when you get the price of SLB LoadBalancer:```json{"LoadBalancerName": "cc-test","Bandwidth": 6,"PaymentType": "PayAsYouGo","AddressType": "internet","LoadBalancerSpec": "slb.s3.small","InternetChargeType": "paybybandwidth"} See `DesireAttributes` below.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str product: The product Code represents the product to be operated. Currently supported products and resources can be queried at the following link: [supported-services-and-resource-types](https://help.aliyun.com/zh/cloud-control-api/product-overview/supported-services-and-resource-types).
    :param builtins.str resource_code: Resource Code, if there is a parent resource, split with `::`, such as VPC::VSwitch. The supported resource Code can be obtained from the following link: [supported-services-and-resource-types](https://help.aliyun.com/zh/cloud-control-api/product-overview/supported-services-and-resource-types).
    """
    __args__ = dict()
    __args__['desireAttributes'] = desire_attributes
    __args__['outputFile'] = output_file
    __args__['product'] = product
    __args__['resourceCode'] = resource_code
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:cloudcontrol/getPrices:getPrices', __args__, opts=opts, typ=GetPricesResult)
    return __ret__.apply(lambda __response__: GetPricesResult(
        desire_attributes=pulumi.get(__response__, 'desire_attributes'),
        id=pulumi.get(__response__, 'id'),
        output_file=pulumi.get(__response__, 'output_file'),
        prices=pulumi.get(__response__, 'prices'),
        product=pulumi.get(__response__, 'product'),
        resource_code=pulumi.get(__response__, 'resource_code')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['AccountArgs', 'Account']

@pulumi.input_type
class AccountArgs:
    def __init__(__self__, *,
                 account_name: pulumi.Input[builtins.str],
                 account_password: pulumi.Input[builtins.str],
                 instance_id: pulumi.Input[builtins.str],
                 account_description: Optional[pulumi.Input[builtins.str]] = None,
                 character_type: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Account resource.
        :param pulumi.Input[builtins.str] account_name: The new password.
               
               - The password must contain at least three of the following character types: uppercase letters, lowercase letters, digits, and special characters. Special characters include `! # $ % ^ & * ( ) _ + - =`
               - The password must be 8 to 32 characters in length.
        :param pulumi.Input[builtins.str] account_password: The password of the database account. The password must be 8 to 32 characters in length. It can contain at least three types of the following characters: uppercase letters, lowercase letters, digits, and special characters. Special characters include ! # $ % ^ & \\* ( ) \\_ + - =
        :param pulumi.Input[builtins.str] instance_id: The account whose password needs to be reset. Set the value to `root`.
        :param pulumi.Input[builtins.str] account_description: Account comment information.
               
               > **NOTE:**  Call the ModifyAccountDescription interface to set the account description information before this parameter is returned.
        :param pulumi.Input[builtins.str] character_type: The role type of the instance. Value description
               
               - When the instance type is sharded cluster, charactertype is required. The values are db and cs.
               - When the instance type is a replica set, charactertype can be null or pass in normal.
        """
        pulumi.set(__self__, "account_name", account_name)
        pulumi.set(__self__, "account_password", account_password)
        pulumi.set(__self__, "instance_id", instance_id)
        if account_description is not None:
            pulumi.set(__self__, "account_description", account_description)
        if character_type is not None:
            pulumi.set(__self__, "character_type", character_type)

    @property
    @pulumi.getter(name="accountName")
    def account_name(self) -> pulumi.Input[builtins.str]:
        """
        The new password.

        - The password must contain at least three of the following character types: uppercase letters, lowercase letters, digits, and special characters. Special characters include `! # $ % ^ & * ( ) _ + - =`
        - The password must be 8 to 32 characters in length.
        """
        return pulumi.get(self, "account_name")

    @account_name.setter
    def account_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "account_name", value)

    @property
    @pulumi.getter(name="accountPassword")
    def account_password(self) -> pulumi.Input[builtins.str]:
        """
        The password of the database account. The password must be 8 to 32 characters in length. It can contain at least three types of the following characters: uppercase letters, lowercase letters, digits, and special characters. Special characters include ! # $ % ^ & \\* ( ) \\_ + - =
        """
        return pulumi.get(self, "account_password")

    @account_password.setter
    def account_password(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "account_password", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[builtins.str]:
        """
        The account whose password needs to be reset. Set the value to `root`.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="accountDescription")
    def account_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Account comment information.

        > **NOTE:**  Call the ModifyAccountDescription interface to set the account description information before this parameter is returned.
        """
        return pulumi.get(self, "account_description")

    @account_description.setter
    def account_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_description", value)

    @property
    @pulumi.getter(name="characterType")
    def character_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The role type of the instance. Value description

        - When the instance type is sharded cluster, charactertype is required. The values are db and cs.
        - When the instance type is a replica set, charactertype can be null or pass in normal.
        """
        return pulumi.get(self, "character_type")

    @character_type.setter
    def character_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "character_type", value)


@pulumi.input_type
class _AccountState:
    def __init__(__self__, *,
                 account_description: Optional[pulumi.Input[builtins.str]] = None,
                 account_name: Optional[pulumi.Input[builtins.str]] = None,
                 account_password: Optional[pulumi.Input[builtins.str]] = None,
                 character_type: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Account resources.
        :param pulumi.Input[builtins.str] account_description: Account comment information.
               
               > **NOTE:**  Call the ModifyAccountDescription interface to set the account description information before this parameter is returned.
        :param pulumi.Input[builtins.str] account_name: The new password.
               
               - The password must contain at least three of the following character types: uppercase letters, lowercase letters, digits, and special characters. Special characters include `! # $ % ^ & * ( ) _ + - =`
               - The password must be 8 to 32 characters in length.
        :param pulumi.Input[builtins.str] account_password: The password of the database account. The password must be 8 to 32 characters in length. It can contain at least three types of the following characters: uppercase letters, lowercase letters, digits, and special characters. Special characters include ! # $ % ^ & \\* ( ) \\_ + - =
        :param pulumi.Input[builtins.str] character_type: The role type of the instance. Value description
               
               - When the instance type is sharded cluster, charactertype is required. The values are db and cs.
               - When the instance type is a replica set, charactertype can be null or pass in normal.
        :param pulumi.Input[builtins.str] instance_id: The account whose password needs to be reset. Set the value to `root`.
        :param pulumi.Input[builtins.str] status: Account Status
        """
        if account_description is not None:
            pulumi.set(__self__, "account_description", account_description)
        if account_name is not None:
            pulumi.set(__self__, "account_name", account_name)
        if account_password is not None:
            pulumi.set(__self__, "account_password", account_password)
        if character_type is not None:
            pulumi.set(__self__, "character_type", character_type)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="accountDescription")
    def account_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Account comment information.

        > **NOTE:**  Call the ModifyAccountDescription interface to set the account description information before this parameter is returned.
        """
        return pulumi.get(self, "account_description")

    @account_description.setter
    def account_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_description", value)

    @property
    @pulumi.getter(name="accountName")
    def account_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The new password.

        - The password must contain at least three of the following character types: uppercase letters, lowercase letters, digits, and special characters. Special characters include `! # $ % ^ & * ( ) _ + - =`
        - The password must be 8 to 32 characters in length.
        """
        return pulumi.get(self, "account_name")

    @account_name.setter
    def account_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_name", value)

    @property
    @pulumi.getter(name="accountPassword")
    def account_password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The password of the database account. The password must be 8 to 32 characters in length. It can contain at least three types of the following characters: uppercase letters, lowercase letters, digits, and special characters. Special characters include ! # $ % ^ & \\* ( ) \\_ + - =
        """
        return pulumi.get(self, "account_password")

    @account_password.setter
    def account_password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_password", value)

    @property
    @pulumi.getter(name="characterType")
    def character_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The role type of the instance. Value description

        - When the instance type is sharded cluster, charactertype is required. The values are db and cs.
        - When the instance type is a replica set, charactertype can be null or pass in normal.
        """
        return pulumi.get(self, "character_type")

    @character_type.setter
    def character_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "character_type", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The account whose password needs to be reset. Set the value to `root`.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Account Status
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("alicloud:mongodb/account:Account")
class Account(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_description: Optional[pulumi.Input[builtins.str]] = None,
                 account_name: Optional[pulumi.Input[builtins.str]] = None,
                 account_password: Optional[pulumi.Input[builtins.str]] = None,
                 character_type: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        ## Import

        Mongo D B Account can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:mongodb/account:Account example <instance_id>:<account_name>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_description: Account comment information.
               
               > **NOTE:**  Call the ModifyAccountDescription interface to set the account description information before this parameter is returned.
        :param pulumi.Input[builtins.str] account_name: The new password.
               
               - The password must contain at least three of the following character types: uppercase letters, lowercase letters, digits, and special characters. Special characters include `! # $ % ^ & * ( ) _ + - =`
               - The password must be 8 to 32 characters in length.
        :param pulumi.Input[builtins.str] account_password: The password of the database account. The password must be 8 to 32 characters in length. It can contain at least three types of the following characters: uppercase letters, lowercase letters, digits, and special characters. Special characters include ! # $ % ^ & \\* ( ) \\_ + - =
        :param pulumi.Input[builtins.str] character_type: The role type of the instance. Value description
               
               - When the instance type is sharded cluster, charactertype is required. The values are db and cs.
               - When the instance type is a replica set, charactertype can be null or pass in normal.
        :param pulumi.Input[builtins.str] instance_id: The account whose password needs to be reset. Set the value to `root`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AccountArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        Mongo D B Account can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:mongodb/account:Account example <instance_id>:<account_name>
        ```

        :param str resource_name: The name of the resource.
        :param AccountArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AccountArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_description: Optional[pulumi.Input[builtins.str]] = None,
                 account_name: Optional[pulumi.Input[builtins.str]] = None,
                 account_password: Optional[pulumi.Input[builtins.str]] = None,
                 character_type: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AccountArgs.__new__(AccountArgs)

            __props__.__dict__["account_description"] = account_description
            if account_name is None and not opts.urn:
                raise TypeError("Missing required property 'account_name'")
            __props__.__dict__["account_name"] = account_name
            if account_password is None and not opts.urn:
                raise TypeError("Missing required property 'account_password'")
            __props__.__dict__["account_password"] = None if account_password is None else pulumi.Output.secret(account_password)
            __props__.__dict__["character_type"] = character_type
            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["status"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["accountPassword"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Account, __self__).__init__(
            'alicloud:mongodb/account:Account',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_description: Optional[pulumi.Input[builtins.str]] = None,
            account_name: Optional[pulumi.Input[builtins.str]] = None,
            account_password: Optional[pulumi.Input[builtins.str]] = None,
            character_type: Optional[pulumi.Input[builtins.str]] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None) -> 'Account':
        """
        Get an existing Account resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_description: Account comment information.
               
               > **NOTE:**  Call the ModifyAccountDescription interface to set the account description information before this parameter is returned.
        :param pulumi.Input[builtins.str] account_name: The new password.
               
               - The password must contain at least three of the following character types: uppercase letters, lowercase letters, digits, and special characters. Special characters include `! # $ % ^ & * ( ) _ + - =`
               - The password must be 8 to 32 characters in length.
        :param pulumi.Input[builtins.str] account_password: The password of the database account. The password must be 8 to 32 characters in length. It can contain at least three types of the following characters: uppercase letters, lowercase letters, digits, and special characters. Special characters include ! # $ % ^ & \\* ( ) \\_ + - =
        :param pulumi.Input[builtins.str] character_type: The role type of the instance. Value description
               
               - When the instance type is sharded cluster, charactertype is required. The values are db and cs.
               - When the instance type is a replica set, charactertype can be null or pass in normal.
        :param pulumi.Input[builtins.str] instance_id: The account whose password needs to be reset. Set the value to `root`.
        :param pulumi.Input[builtins.str] status: Account Status
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AccountState.__new__(_AccountState)

        __props__.__dict__["account_description"] = account_description
        __props__.__dict__["account_name"] = account_name
        __props__.__dict__["account_password"] = account_password
        __props__.__dict__["character_type"] = character_type
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["status"] = status
        return Account(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountDescription")
    def account_description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Account comment information.

        > **NOTE:**  Call the ModifyAccountDescription interface to set the account description information before this parameter is returned.
        """
        return pulumi.get(self, "account_description")

    @property
    @pulumi.getter(name="accountName")
    def account_name(self) -> pulumi.Output[builtins.str]:
        """
        The new password.

        - The password must contain at least three of the following character types: uppercase letters, lowercase letters, digits, and special characters. Special characters include `! # $ % ^ & * ( ) _ + - =`
        - The password must be 8 to 32 characters in length.
        """
        return pulumi.get(self, "account_name")

    @property
    @pulumi.getter(name="accountPassword")
    def account_password(self) -> pulumi.Output[builtins.str]:
        """
        The password of the database account. The password must be 8 to 32 characters in length. It can contain at least three types of the following characters: uppercase letters, lowercase letters, digits, and special characters. Special characters include ! # $ % ^ & \\* ( ) \\_ + - =
        """
        return pulumi.get(self, "account_password")

    @property
    @pulumi.getter(name="characterType")
    def character_type(self) -> pulumi.Output[builtins.str]:
        """
        The role type of the instance. Value description

        - When the instance type is sharded cluster, charactertype is required. The values are db and cs.
        - When the instance type is a replica set, charactertype can be null or pass in normal.
        """
        return pulumi.get(self, "character_type")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        The account whose password needs to be reset. Set the value to `root`.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Account Status
        """
        return pulumi.get(self, "status")

